Installation — arginfer 0.1.dev80+gf4bcddf.d20210325 documentation

# Installation

To install `arginfer` simply run:

    $ pip install -i https://test.pypi.org/simple/ arginfer

or:

    $ python3 -m pip install arginfer --user

Python 3.6, or a more recent version, is required. The software has been tested on MacOSX.

Once installed, `arginfer`'s Command Line Interface (CLI) can be accessed via:

    $ python3 -m arginfer

or

    $ arginfer

Alternatively, the Python API allows more control of the inference process.